# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%d min verbleiben zum Lesen",
    "(active)": "(aktiv)",
    "Also available in:": "Auch verfügbar in:",
    "Archive": "Archiv",
    "Atom feed": "Atom-Feed",
    "Authors": "Autoren",
    "Categories": "Kategorien",
    "Comments": "Kommentare",
    "LANGUAGE": "Deutsch",
    "Languages:": "Sprachen:",
    "More posts about %s": "Weitere Einträge über %s",
    "Newer posts": "Neuere Einträge",
    "Next post": "Nächster Eintrag",
    "Next": "Nächster Eintrag",
    "No posts found.": "Keine Einträge gefunden.",
    "Nothing found.": "Nichts gefunden.",
    "Older posts": "Ältere Einträge",
    "Original site": "Original-Seite",
    "Posted:": "Veröffentlicht:",
    "Posts about %s": "Einträge über %s",
    "Posts by %s": "Einträge von %s",
    "Posts for year %s": "Einträge aus dem Jahr %s",
    "Posts for {month_day_year}": "Einträge vom {month_day_year}",
    "Posts for {month_year}": "Einträge aus {month_year}",
    "Previous post": "Vorheriger Eintrag",
    "Previous": "Vorheriger Eintrag",
    "Publication date": "Veröffentlichungsdatum",
    "RSS feed": "RSS-Feed",
    "Read in English": "Auf Deutsch lesen",
    "Read more": "Weiterlesen",
    "Skip to main content": "Springe zum Hauptinhalt",
    "Source": "Source",
    "Subcategories:": "Unterkategorien:",
    "Tags and Categories": "Tags und Kategorien",
    "Tags": "Tags",
    "Toggle navigation": "Navigation umschalten",
    "Uncategorized": "Nicht kategorisiert",
    "Up": "Nach oben",
    "Updates": "Updates",
    "Write your page here.": "Schreibe hier deinen Seiteninhalt hin.",
    "Write your post here.": "Schreibe hier deinen Eintrag hin.",
    "old posts, page %d": "Ältere Einträge, Seite %d",
    "page %d": "Seite %d",
    "updated": "aktualisiert",
}



# -*- coding: utf-8 -*-

# Copyright © 2012-2025 Roberto Alsina and others.

# Permission is hereby granted, free of charge, to any
# person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the
# Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
# OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""Generate redirections."""


import os

from nikola.plugin_categories import Task
from nikola import utils


class Redirect(Task):
    """Generate redirections."""

    name = "redirect"

    def gen_tasks(self):
        """Generate redirections tasks."""
        kw = {
            'redirections': self.site.config['REDIRECTIONS'],
            'output_folder': self.site.config['OUTPUT_FOLDER'],
            'filters': self.site.config['FILTERS'],
            'index_file': self.site.config['INDEX_FILE'],
        }

        yield self.group_task()
        if kw['redirections']:
            for src, dst in kw["redirections"]:
                src_path = os.path.join(kw["output_folder"], src.lstrip('/'))
                if src_path.endswith("/"):
                    src_path += kw['index_file']
                yield utils.apply_filters({
                    'basename': self.name,
                    'name': src_path,
                    'targets': [src_path],
                    'actions': [(utils.create_redirect, (src_path, dst))],
                    'clean': True,
                    'uptodate': [utils.config_changed(kw, 'nikola.plugins.task.redirect')],
                }, kw["filters"])



# -*- encoding:utf-8 -*-
"""Autogenerated file, do not edit. Submit translations on Transifex."""

MESSAGES = {
    "%d min remaining to read": "%d min rămase pentru citire",
    "(active)": "(activ)",
    "Also available in:": "Valabil și în:",
    "Archive": "Arhivă",
    "Atom feed": "Atom flux",
    "Authors": "Autori",
    "Categories": "Categorii",
    "Comments": "Comentarii",
    "LANGUAGE": "Română",
    "Languages:": "Traducere:",
    "More posts about %s": "Mai multe articole despre %s",
    "Newer posts": "Articole recente",
    "Next post": "Următorul articol",
    "Next": "Următorul",
    "No posts found.": "Nici un articol găsit.",
    "Nothing found.": "Nimic găsit.",
    "Older posts": "Articole vechi",
    "Original site": "Pagină originală",
    "Posted:": "Postat:",
    "Posts about %s": "Articole despre %s",
    "Posts by %s": "Articole de %s",
    "Posts for year %s": "Articolele pentru anul %s",
    "Posts for {month_day_year}": "Articole din  {month_day_year}",
    "Posts for {month_year}": "Articole din {month_year}",
    "Previous post": "Articole anterioare",
    "Previous": "Anterior",
    "Publication date": "Data publicației",
    "RSS feed": "RSS flux",
    "Read in English": "Citește în Română",
    "Read more": "Citește mai mult",
    "Skip to main content": "Sări la conținutul principal",
    "Source": "Sursă",
    "Subcategories:": "Subcategorii:",
    "Tags and Categories": "Etichete și Categorii",
    "Tags": "Etichete",
    "Toggle navigation": "Activează navigația",
    "Uncategorized": "Necategorizat",
    "Up": "Sus",
    "Updates": "Actualizări",
    "Write your page here.": "Scrie-ți pagina aici.",
    "Write your post here.": "Scrie-ți articolul aici.",
    "old posts, page %d": "articole vechi, pagina %d",
    "page %d": "pagina %d",
    "updated": "actualizat",
}



# -*- coding: utf-8 -*-

# Copyright © 2012-2025 Roberto Alsina and others.

# Permission is hereby granted, free of charge, to any
# person obtaining a copy of this software and associated
# documentation files (the "Software"), to deal in the
# Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the
# Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice
# shall be included in all copies or substantial portions of
# the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
# OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
# OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

"""Logging support."""

import enum
import logging
import warnings

from nikola import DEBUG, TEMPLATES_TRACE

__all__ = (
    "get_logger",
    "LOGGER",
)


# Handlers/formatters
class ApplicationWarning(Exception):
    """An application warning, raised in strict mode."""

    pass


class StrictModeExceptionHandler(logging.StreamHandler):
    """A logging handler that raises an exception on warnings."""

    def emit(self, record: logging.LogRecord) -> None:
        """Emit a logging record."""
        if record.levelno >= logging.WARNING:
            raise ApplicationWarning(self.format(record))


class ColorfulFormatter(logging.Formatter):
    """Stream handler with colors."""

    _colorful = False

    def format(self, record: logging.LogRecord) -> str:
        """Format a message and add colors to it."""
        message = super().format(record)
        return self.wrap_in_color(record).format(message)

    def wrap_in_color(self, record: logging.LogRecord) -> str:
        """Return the colorized string for this record."""
        if not self._colorful:
            return "{}"
        if record.levelno >= logging.ERROR:
            return "\033[1;31m{}\033[0m"
        elif record.levelno >= logging.WARNING:
            return "\033[1;33m{}\033[0m"
        elif record.levelno >= logging.INFO:
            return "\033[1m{}\033[0m"
        return "\033[37m{}\033[0m"


# Initial configuration
class LoggingMode(enum.Enum):
    """Logging mode options."""

    NORMAL = 0
    STRICT = 1
    QUIET = 2


_LOGGING_FMT = "[%(asctime)s] %(levelname)s: %(name)s: %(message)s"
_LOGGING_DATEFMT = "%Y-%m-%d %H:%M:%S"


def configure_logging(logging_mode: LoggingMode = LoggingMode.NORMAL) -> None:
    """Configure logging for Nikola.

    This method can be called multiple times, previous configuration will be overridden.
    """
    if DEBUG:
        logging.root.level = logging.DEBUG
    else:
        logging.root.level = logging.INFO

    if logging_mode == LoggingMode.QUIET:
        logging.root.handlers = []
        return

    handler = logging.StreamHandler()
    handler.setFormatter(ColorfulFormatter(fmt=_LOGGING_FMT, datefmt=_LOGGING_DATEFMT))

    handlers = [handler]
    if logging_mode == LoggingMode.STRICT:
        handlers.append(StrictModeExceptionHandler())

    logging.root.handlers = handlers


configure_logging()


# For compatibility with old code written with Logbook in mind
# TODO remove in v9
def patch_notice_level(logger: logging.Logger) -> logging.Logger:
    """Patch logger to issue WARNINGs with logger.notice."""
    logger.notice = logger.warning
    return logger


# User-facing loggers
def get_logger(name: str, handlers=None) -> logging.Logger:
    """Get a logger with handlers attached."""
    logger = logging.getLogger(name)
    if handlers is not None:
        for h in handlers:
            logger.addHandler(h)
    return patch_notice_level(logger)


LOGGER = get_logger("Nikola")
TEMPLATES_LOGGER = get_logger("nikola.templates")


def init_template_trace_logging(filename: str) -> None:
    """Initialize the tracing of the template system.

    This tells a theme designer which templates are being exercised
    and for which output files, and, if applicable, input files.

    As there is lots of other stuff happening on the normal output stream,
    this info is also written to a log file.
    """
    TEMPLATES_LOGGER.level = logging.DEBUG
    formatter = logging.Formatter(
        fmt=_LOGGING_FMT,
        datefmt=_LOGGING_DATEFMT,
    )
    shandler = logging.StreamHandler()
    shandler.setFormatter(formatter)
    shandler.setLevel(logging.DEBUG)

    fhandler = logging.FileHandler(filename, encoding="UTF-8")
    fhandler.setFormatter(formatter)
    fhandler.setLevel(logging.DEBUG)

    TEMPLATES_LOGGER.handlers = [shandler, fhandler]
    TEMPLATES_LOGGER.propagate = False

    TEMPLATES_LOGGER.info("Template usage being traced to file %s", filename)


if DEBUG or TEMPLATES_TRACE:
    init_template_trace_logging("templates_trace.log")


# Push warnings to logging
def showwarning(message, category, filename, lineno, file=None, line=None):
    """Show a warning (from the warnings module) to the user."""
    try:
        n = category.__name__
    except AttributeError:
        n = str(category)
    get_logger(n).warning("{0}:{1}: {2}".format(filename, lineno, message))


warnings.showwarning = showwarning



# -*- coding: utf-8 -*-
#
# Copyright © 2013 Michael Rabbitt.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
# Warning: URL formats of "raw" gists are undocummented and subject to change.
# See also:  https://developer.github.com/v3/gists/
#
# Inspired by "[Python] reStructuredText GitHub Gist directive"
# (https://gist.github.com/brianhsu/1407759), public domain by Brian Hsu
"""
Extension to Python Markdown for Embedded Gists (gist.github.com).

Basic Example:

    Text of the gist:
    [:gist: 4747847]

Example with filename:

    Text of the gist:
    [:gist: 4747847 zen.py]

Basic Example with hexidecimal id:

    Text of the gist:
    [:gist: c4a43d6fdce612284ac0]

Example with hexidecimal id filename:

    Text of the gist:
    [:gist: c4a43d6fdce612284ac0 cow.txt]

Example using reStructuredText syntax:

    Text of the gist:
    .. gist:: 4747847 zen.py

Example using hexidecimal ID with reStructuredText syntax:

    Text of the gist:
    .. gist:: c4a43d6fdce612284ac0

Example using hexidecimal ID and filename with reStructuredText syntax:

    Text of the gist:
    .. gist:: c4a43d6fdce612284ac0 cow.txt

Error Case: non-existent Gist ID:

    Text of the gist:
    [:gist: 0]

Error Case: non-existent file:

    Text of the gist:
    [:gist: 4747847 doesntexist.py]
"""

import requests
import xml.etree.ElementTree as etree

from nikola.plugin_categories import MarkdownExtension
from nikola.utils import get_logger

try:
    from markdown.extensions import Extension
    from markdown.inlinepatterns import InlineProcessor
    from markdown.util import AtomicString
except ImportError:
    # No need to catch this, if you try to use this without Markdown,
    # the markdown compiler will fail first
    Extension = InlineProcessor = AtomicString = object


LOGGER = get_logger('compile_markdown.mdx_gist')

GIST_JS_URL = "https://gist.github.com/{0}.js"
GIST_FILE_JS_URL = "https://gist.github.com/{0}.js?file={1}"
GIST_RAW_URL = "https://gist.githubusercontent.com/raw/{0}"
GIST_FILE_RAW_URL = "https://gist.githubusercontent.com/raw/{0}/{1}"

GIST_MD_RE = r'\[:gist:\s*(?P<gist_id>\S+)(?:\s*(?P<filename>.+?))?\s*\]'
GIST_RST_RE = r'(?m)^\.\.\s*gist::\s*(?P<gist_id>[^\]\s]+)(?:\s*(?P<filename>.+?))?\s*$'


class GistFetchException(Exception):
    """Raised when attempt to fetch content of a Gist from github.com fails."""

    def __init__(self, url, status_code):
        """Initialize the exception."""
        Exception.__init__(self)
        self.message = 'Received a {0} response from Gist URL: {1}'.format(
            status_code, url)


class GistPattern(InlineProcessor):
    """InlinePattern for footnote markers in a document's body text."""

    def __init__(self, pattern, configs):
        """Initialize the pattern."""
        InlineProcessor.__init__(self, pattern)

    def get_raw_gist_with_filename(self, gist_id, filename):
        """Get raw gist text for a filename."""
        url = GIST_FILE_RAW_URL.format(gist_id, filename)
        resp = requests.get(url)

        if not resp.ok:
            raise GistFetchException(url, resp.status_code)

        return resp.text

    def get_raw_gist(self, gist_id):
        """Get raw gist text."""
        url = GIST_RAW_URL.format(gist_id)
        resp = requests.get(url)

        if not resp.ok:
            raise GistFetchException(url, resp.status_code)

        return resp.text

    def handleMatch(self, m, _):
        """Handle pattern match."""
        # The third arg is "data", wider context around the match; we don't need it.
        gist_id = m.group('gist_id')
        gist_file = m.group('filename')

        gist_elem = etree.Element('div')
        gist_elem.set('class', 'gist')
        script_elem = etree.SubElement(gist_elem, 'script')

        noscript_elem = etree.SubElement(gist_elem, 'noscript')

        try:
            if gist_file:
                script_elem.set('src', GIST_FILE_JS_URL.format(
                    gist_id, gist_file))
                raw_gist = (self.get_raw_gist_with_filename(
                    gist_id, gist_file))

            else:
                script_elem.set('src', GIST_JS_URL.format(gist_id))
                raw_gist = (self.get_raw_gist(gist_id))

            # Insert source as <pre/> within <noscript>
            pre_elem = etree.SubElement(noscript_elem, 'pre')
            pre_elem.text = AtomicString(raw_gist)

        except GistFetchException as e:
            LOGGER.warning(e.message)
            warning_comment = etree.Comment(' WARNING: {0} '.format(e.message))
            noscript_elem.append(warning_comment)

        return (gist_elem, m.start(0), m.end(0))


class GistExtension(MarkdownExtension, Extension):
    """Gist extension for Markdown."""

    def __init__(self, configs={}):
        """Initialize the extension."""
        # set extension defaults
        self.config = {}

        # Override defaults with user settings
        for key, value in configs:
            self.setConfig(key, value)

    def extendMarkdown(self, md, md_globals=None):
        """Extend Markdown."""
        gist_md_pattern = GistPattern(GIST_MD_RE, self.getConfigs())
        gist_md_pattern.md = md
        md.inlinePatterns.register(gist_md_pattern, 'gist', 175)

        gist_rst_pattern = GistPattern(GIST_RST_RE, self.getConfigs())
        gist_rst_pattern.md = md
        md.inlinePatterns.register(gist_rst_pattern, 'gist-rst', 176)

        md.registerExtension(self)


def makeExtension(configs=None):  # pragma: no cover
    """Make Markdown extension."""
    return GistExtension(configs)


if __name__ == '__main__':
    import doctest

    doctest.testmod(optionflags=(doctest.NORMALIZE_WHITESPACE +
                                 doctest.REPORT_NDIFF))
